# Youtube2Images Package to convert any youtube video to frame images

## about

Python Package to convert youtube video to images 

# Installation

```
pip install Youtube2Images
or in colab google cloud
!pip install Youtube2Images
```

## Usage for get frames images 

```
from  Youtube2Images import you2img 
```
```
dir_name='Mozart'
youtube_url='https://youtu.be/7lC1lRz5Z_s'
frame_name='mozart'
total_images=20
folder_images='Mozart_Images'
you2img.youtub2imgs(dir_name,youtube_url,frame_name,total_images,folder_images)

```

## Tutorial 
u can see tutorial in colab 

https://colab.research.google.com/drive/1MpzdcXOL-vzY7M7Arb5JVF4CR0l0T4Ly

 

